@@ -15,12 +15,12 @@ class Solver4Point(object):
     """
     def __init__(self, lensModel, solver_type='PROFILE'):
         self._solver_type = solver_type  # supported:
-        if not lensModel.lens_model_list[0] in ['SPEP', 'SPEMD', 'PEMD', 'SIE', 'NIE', 'NFW_ELLIPSE',
+        if not lensModel.lens_model_list[0] in ['SPEP', 'SPEMD', 'PEMD', 'SIE', 'NIE', 'NFW_ELLIPSE', 'NFW_ELLIPSE_CSE',
                                                 'SHAPELETS_CART', 'CNFW_ELLIPSE', 'EPL']:
             raise ValueError("first lens model must be supported by the solver: 'SPEP', 'SPEMD', 'PEMD',"
-                             " 'SIE', 'NIE', 'EPL', 'NFW_ELLIPSE', 'SHAPELETS_CART', 'CNFW_ELLIPSE'. "
+                             " 'SIE', 'NIE', 'EPL', 'NFW_ELLIPSE', 'NFW_ELLIPSE_CSE', 'SHAPELETS_CART', 'CNFW_ELLIPSE'."
                              "Your choice was %s" % lensModel.lens_model_list[0])
-        if not solver_type in ['PROFILE', 'PROFILE_SHEAR']:
+        if solver_type not in ['PROFILE', 'PROFILE_SHEAR']:
             raise ValueError("solver_type %s not supported! Choose from 'PROFILE', 'PROFILE_SHEAR'"
                              % solver_type)
         if solver_type in ['PROFILE_SHEAR']:
@@ -42,7 +42,7 @@ class Solver4Point(object):
 
         :param x_pos: list of image positions (x-axis)
         :param y_pos: list of image position (y-axis)
-        :param init: initial parameters
+        :param xtol: numerical tolerance level
         :param kwargs_list: list of lens model kwargs
         :return: updated lens model that satisfies the lens equation for the point sources
         """
@@ -67,7 +67,7 @@ class Solver4Point(object):
         return kwargs, accuracy
 
     def solve(self, x_pos, y_pos, init, kwargs_list, a, xtol=1.49012e-10):
-        x = scipy.optimize.fsolve(self._F, init, args=(x_pos, y_pos, kwargs_list, a), xtol=xtol)#, factor=0.1)
+        x = scipy.optimize.fsolve(self._F, init, args=(x_pos, y_pos, kwargs_list, a), xtol=xtol)  # , factor=0.1)
         return x
 
     def _F(self, x, x_pos, y_pos, kwargs_list, a=np.zeros(6)):
@@ -95,8 +95,6 @@ class Solver4Point(object):
     def _subtract_constraint(x_sub, y_sub):
         """
 
-        :param x_pos:
-        :param y_pos:
         :param x_sub:
         :param y_sub:
         :return:
@@ -119,7 +117,7 @@ class Solver4Point(object):
         :return: updated kwargs_list
         """
         if self._solver_type == 'PROFILE_SHEAR_GAMMA_PSI':
-            phi_G = x[5]# % (2 * np.pi)
+            phi_G = x[5]  # % (2 * np.pi)
             kwargs_list[1]['psi_ext'] = phi_G
         if self._solver_type == 'PROFILE_SHEAR':
             phi_G = x[5] % np.pi
@@ -129,21 +127,21 @@ class Solver4Point(object):
             kwargs_list[1]['gamma2'] = gamma2
         lens_model = self._lens_mode_list[0]
         if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL']:
-            [theta_E, e1, e2, center_x, center_y, no_sens_param] = x
+            [theta_E, e1, e2, center_x, center_y, _] = x
             kwargs_list[0]['theta_E'] = theta_E
             kwargs_list[0]['e1'] = e1
             kwargs_list[0]['e2'] = e2
             kwargs_list[0]['center_x'] = center_x
             kwargs_list[0]['center_y'] = center_y
-        elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE']:
-            [alpha_Rs, e1, e2, center_x, center_y, no_sens_param] = x
+        elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE', 'NFW_ELLIPSE_CSE']:
+            [alpha_Rs, e1, e2, center_x, center_y, _] = x
             kwargs_list[0]['alpha_Rs'] = alpha_Rs
             kwargs_list[0]['e1'] = e1
             kwargs_list[0]['e2'] = e2
             kwargs_list[0]['center_x'] = center_x
             kwargs_list[0]['center_y'] = center_y
         elif lens_model in ['SHAPELETS_CART']:
-            [c10, c01, c20, c11, c02, no_sens_param] = x
+            [c10, c01, c20, c11, c02, _] = x
             coeffs = list(kwargs_list[0]['coeffs'])
             coeffs[1: 6] = [c10, c01, c20, c11, c02]
             kwargs_list[0]['coeffs'] = coeffs
@@ -158,17 +156,17 @@ class Solver4Point(object):
         :return:
         """
         if self._solver_type == 'PROFILE_SHEAR_GAMMA_PSI':
-            phi_ext = kwargs_list[1]['psi_ext']# % (np.pi)
-            #e1 = kwargs_list[1]['e1']
-            #e2 = kwargs_list[1]['e2']
-            #phi_ext, gamma_ext = param_util.ellipticity2phi_gamma(e1, e2)
+            phi_ext = kwargs_list[1]['psi_ext']  # % (np.pi)
+            # e1 = kwargs_list[1]['e1']
+            # e2 = kwargs_list[1]['e2']
+            # phi_ext, gamma_ext = param_util.ellipticity2phi_gamma(e1, e2)
         elif self._solver_type == 'PROFILE_SHEAR':
             gamma1 = kwargs_list[1]['gamma1']
             gamma2 = kwargs_list[1]['gamma2']
             phi_ext, gamma_ext = param_util.shear_cartesian2polar(gamma1, gamma2)
-            #phi_G_no_sense, gamma_ext = param_util.ellipticity2phi_gamma(kwargs_list[1]['e1'], kwargs_list[1]['e2'])
-            #e1, e2 = param_util.phi_gamma_ellipticity(phi_G, gamma_ext)
-            #kwargs_list[1]['e1'] = e1
+            # phi_G_no_sense, gamma_ext = param_util.ellipticity2phi_gamma(kwargs_list[1]['e1'], kwargs_list[1]['e2'])
+            # e1, e2 = param_util.phi_gamma_ellipticity(phi_G, gamma_ext)
+            # kwargs_list[1]['e1'] = e1
         else:
             phi_ext = 0
         lens_model = self._lens_mode_list[0]
@@ -179,7 +177,7 @@ class Solver4Point(object):
             center_y = kwargs_list[0]['center_y']
             theta_E = kwargs_list[0]['theta_E']
             x = [theta_E, e1, e2, center_x, center_y, phi_ext]
-        elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE']:
+        elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE', 'NFW_ELLIPSE_CSE']:
             e1 = kwargs_list[0]['e1']
             e2 = kwargs_list[0]['e2']
             center_x = kwargs_list[0]['center_x']
@@ -207,14 +205,14 @@ class Solver4Point(object):
         kwargs_lens = kwargs_lens_init[0]
         if self._solver_type in ['PROFILE_SHEAR', 'PROFILE_SHEAR_GAMMA_PSI']:
             pass
-            #kwargs_fixed_lens_list[1]['psi_ext'] = kwargs_lens_init[1]['psi_ext']
+            # kwargs_fixed_lens_list[1]['psi_ext'] = kwargs_lens_init[1]['psi_ext']
         if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL']:
             kwargs_fixed['theta_E'] = kwargs_lens['theta_E']
             kwargs_fixed['e1'] = kwargs_lens['e1']
             kwargs_fixed['e2'] = kwargs_lens['e2']
             kwargs_fixed['center_x'] = kwargs_lens['center_x']
             kwargs_fixed['center_y'] = kwargs_lens['center_y']
-        elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE']:
+        elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE', 'NFW_ELLIPSE_CSE']:
             kwargs_fixed['alpha_Rs'] = kwargs_lens['alpha_Rs']
             kwargs_fixed['e1'] = kwargs_lens['e1']
             kwargs_fixed['e2'] = kwargs_lens['e2']
