@@ -34,6 +34,7 @@ class SinglePlane(ProfileListBase):
         :param x_source: source position
         :param y_source: source position
         :param kwargs_lens: list of keyword arguments of lens model parameters matching the lens model classes
+        :param k:
         :return: fermat potential in arcsec**2 without geometry term (second part of Eqn 1 in Suyu et al. 2013) as a list
         """
 
@@ -135,7 +136,7 @@ class SinglePlane(ProfileListBase):
         mass_3d = 0
         for i, func in enumerate(self.func_list):
             if bool_list[i] is True:
-                kwargs_i = {k:v for k, v in kwargs[i].items() if not k in ['center_x', 'center_y']}
+                kwargs_i = {k: v for k, v in kwargs[i].items() if k not in ['center_x', 'center_y']}
                 mass_3d_i = func.mass_3d_lens(r, **kwargs_i)
                 mass_3d += mass_3d_i
         return mass_3d
@@ -153,7 +154,7 @@ class SinglePlane(ProfileListBase):
         mass_2d = 0
         for i, func in enumerate(self.func_list):
             if bool_list[i] is True:
-                kwargs_i = {k: v for k, v in kwargs[i].items() if not k in ['center_x', 'center_y']}
+                kwargs_i = {k: v for k, v in kwargs[i].items() if k not in ['center_x', 'center_y']}
                 mass_2d_i = func.mass_2d_lens(r, **kwargs_i)
                 mass_2d += mass_2d_i
         return mass_2d
@@ -172,7 +173,7 @@ class SinglePlane(ProfileListBase):
         density = 0
         for i, func in enumerate(self.func_list):
             if bool_list[i] is True:
-                kwargs_i = {k: v for k, v in kwargs[i].items() if not k in ['center_x', 'center_y']}
+                kwargs_i = {k: v for k, v in kwargs[i].items() if k not in ['center_x', 'center_y']}
                 density_i = func.density_lens(r, **kwargs_i)
                 density += density_i
         return density
